function [acc] = stability_selection(trainData, testData, trainLabel, testLabel, options)

for folder = 1 : size(trainData,2)
    train_data = trainData{folder};
    train_label = trainLabel{folder};
    test_data = testData{folder};
    test_label = testLabel{folder};
   
    % select dominating set
     T = corr(train_data,train_label);
     T = abs(T);
     irelevantFea = find(T<0.095);
     train_data(:,irelevantFea) = [];
     test_data(:,irelevantFea) = [];
     T(irelevantFea) = [];
     normX = sqrt(sum(train_data' .^ 2, 2));
     W = (train_data' * train_data) ./ (normX * normX');
     W = abs(W);
     dominateSets = select_MWIS_v1(W,T,options.thresh);
     train_data = train_data(:,dominateSets);
     test_data = test_data(:,dominateSets);
    
    % ensemble lasso     
    [feaRank, ~] = ensemble_lasso(train_data,train_label,options.LassoCardi);
    
    % classification
    for numFea = options.minNum:options.maxNum;
        selectFeaIdx = feaRank(1:numFea);
        train_data_fea = train_data(:,selectFeaIdx);
        test_data_fea = test_data(:,selectFeaIdx);
        model = svmtrain(train_label, train_data_fea,'-t 0 -q') ;%'-c 1'); %  '-t 0');%
        [~, accuracy,~] = svmpredict(test_label,test_data_fea, model,'-q'); % test the training data
        acc(folder,numFea) = accuracy(1);
    end
 end
